tietools.remove_nonfirst_leaves_in_tie_chain
============================================

.. autofunction:: abjad.tools.tietools.remove_nonfirst_leaves_in_tie_chain.remove_nonfirst_leaves_in_tie_chain
   :noindex:
